D12606: contrib: migrate off of a couple of bitbucket URLs

2022-05-04 Thread mharbison72 (Matt Harbison)
mharbison72 created this revision.
Herald added a reviewer: hg-reviewers.
Herald added a subscriber: mercurial-patches.

REVISION SUMMARY
  I noticed this when diffing the thg installer against Mercurial to see what 
was
  missing.  There are a handful of other URLs in i18n and extension example help
  text if anyone cares to update those.

REPOSITORY
  rHG Mercurial

BRANCH
  stable

REVISION DETAIL
  https://phab.mercurial-scm.org/D12606

AFFECTED FILES
  contrib/packaging/wix/readme.rst
  contrib/win32/mercurial.ini

CHANGE DETAILS

diff --git a/contrib/win32/mercurial.ini b/contrib/win32/mercurial.ini
--- a/contrib/win32/mercurial.ini
+++ b/contrib/win32/mercurial.ini
@@ -5,7 +5,7 @@
 ; This file will be replaced by the installer on every upgrade.
 ; Editing this file can cause strange side effects on Vista.
 ;
-; http://bitbucket.org/tortoisehg/stable/issue/135
+; https://foss.heptapod.net/mercurial/tortoisehg/thg/-/issues/135
 ;
 ; To change settings you see in this file, override (or enable) them in
 ; your user Mercurial.ini file, where USERNAME is your Windows user name:
diff --git a/contrib/packaging/wix/readme.rst b/contrib/packaging/wix/readme.rst
--- a/contrib/packaging/wix/readme.rst
+++ b/contrib/packaging/wix/readme.rst
@@ -63,7 +63,7 @@
 TortoiseHG uses the WiX files in this directory.
 
 The code for building TortoiseHG installers lives at
-https://bitbucket.org/tortoisehg/thg-winbuild and is maintained by
+https://foss.heptapod.net/mercurial/tortoisehg/thg-winbuild and is maintained 
by
 Steve Borho (st...@borho.org).
 
 When changing behavior of the WiX installer, be sure to notify



To: mharbison72, #hg-reviewers
Cc: mercurial-patches, mercurial-devel
___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


D12605: diff: add help text to highlight the ability to do "merge diffs"

2022-05-04 Thread mharbison72 (Matt Harbison)
mharbison72 created this revision.
Herald added a reviewer: hg-reviewers.
Herald added a subscriber: mercurial-patches.

REPOSITORY
  rHG Mercurial

BRANCH
  stable

REVISION DETAIL
  https://phab.mercurial-scm.org/D12605

AFFECTED FILES
  mercurial/commands.py
  tests/test-help.t

CHANGE DETAILS

diff --git a/tests/test-help.t b/tests/test-help.t
--- a/tests/test-help.t
+++ b/tests/test-help.t
@@ -644,7 +644,8 @@
   Note:
  'hg diff' may generate unexpected results for merges, as it will
  default to comparing against the working directory's first parent
- changeset if no revisions are specified.
+ changeset if no revisions are specified.  To diff against the conflict
+ regions, you can use '--config diff.merge=yes'.
   
   By default, the working directory files are compared to its first parent.
   To see the differences from another revision, use --from. To see the
-- 
You're receiving this email because of your account on foss.heptapod.net.



___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


mercurial-devel | Failed pipeline for branch/default | a932cad2

2022-05-04 Thread Heptapod


Pipeline #53615 has failed!

Project: mercurial-devel ( https://foss.heptapod.net/mercurial/mercurial-devel )
Branch: branch/default ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/commits/branch/default )

Commit: a932cad2 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/commit/a932cad26d375823e5b08959550b64155b43a01d
 )
Commit Message: branching: merge stable into default
Commit Author: Raphaël Gomès

Pipeline #53615 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/pipelines/53615 ) 
triggered by Administrator ( https://foss.heptapod.net/root )
had 1 failed job.

Job #549732 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/jobs/549732/raw )

Stage: tests
Name: test-chg

-- 
You're receiving this email because of your account on foss.heptapod.net.



___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


mercurial-devel | Failed pipeline for branch/stable | 4420e06c

2022-05-04 Thread Heptapod


Pipeline #53611 has failed!

Project: mercurial-devel ( https://foss.heptapod.net/mercurial/mercurial-devel )
Branch: branch/stable ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/commits/branch/stable )

Commit: 4420e06c ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/commit/4420e06c88106d48b0b3299206c66d23bbf5173d
 )
Commit Message: relnotes: add release notes for 6.1.2
Commit Author: Raphaël Gomès

Pipeline #53611 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/pipelines/53611 ) 
triggered by Administrator ( https://foss.heptapod.net/root )
had 1 failed job.

Job #549695 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/jobs/549695/raw )

Stage: tests
Name: test-py2-rust

-- 
You're receiving this email because of your account on foss.heptapod.net.



___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


D12604: censor: fix [hg update] away from a revision with censored files

2022-05-04 Thread aalekseyev (Arseniy Alekseyev)
aalekseyev created this revision.
Herald added a reviewer: hg-reviewers.
Herald added a subscriber: mercurial-patches.

REPOSITORY
  rHG Mercurial

BRANCH
  default

REVISION DETAIL
  https://phab.mercurial-scm.org/D12604

AFFECTED FILES
  mercurial/filelog.py
  tests/test-censor2.t

CHANGE DETAILS

diff --git a/tests/test-censor2.t b/tests/test-censor2.t
--- a/tests/test-censor2.t
+++ b/tests/test-censor2.t
@@ -19,5 +19,4 @@
   1 files updated, 0 files merged, 0 files removed, 0 files unresolved
   $ cat target
   $ hg update tip
-  abort: file censored data/target:b1c12cf98dc8 (known-bad-output !)
-  [255]
+  1 files updated, 0 files merged, 0 files removed, 0 files unresolved
diff --git a/mercurial/filelog.py b/mercurial/filelog.py
--- a/mercurial/filelog.py
+++ b/mercurial/filelog.py
@@ -202,10 +202,10 @@
 
 # for revisions with renames, we have to go the slow way
 node = self.node(rev)
+if self.iscensored(rev):
+return 0
 if self.renamed(node):
 return len(self.read(node))
-if self.iscensored(rev):
-return 0
 
 # XXX if self.read(node).startswith("\1\n"), this returns (size+4)
 # XXX See also basefilectx.cmp.



To: aalekseyev, #hg-reviewers
Cc: mercurial-patches, mercurial-devel
___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


mercurial-devel | Failed pipeline for branch/default | 9d1e9689

2022-05-04 Thread Heptapod


Pipeline #53610 has failed!

Project: mercurial-devel ( https://foss.heptapod.net/mercurial/mercurial-devel )
Branch: branch/default ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/commits/branch/default )

Commit: 9d1e9689 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/commit/9d1e9689a68f6f4140467e599340d97aeed2ede1
 )
Commit Message: merge: with stable
Commit Author: Augie Fackler

Pipeline #53610 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/pipelines/53610 ) 
triggered by Administrator ( https://foss.heptapod.net/root )
had 1 failed job.

Job #549682 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/jobs/549682/raw )

Stage: tests
Name: test-chg

-- 
You're receiving this email because of your account on foss.heptapod.net.



___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


D12603: diff: graduate merge diffs from experimental and add to tweakdefaults

2022-05-04 Thread durin42 (Augie Fackler)
durin42 created this revision.
Herald added a reviewer: hg-reviewers.
Herald added a subscriber: mercurial-patches.

REVISION SUMMARY
  I've been using this functionality for two years without incident and
  it's been outstanding. In my opinion it's time to both remove the
  experimental warning label and move this straight into tweakdefaults.

REPOSITORY
  rHG Mercurial

BRANCH
  default

REVISION DETAIL
  https://phab.mercurial-scm.org/D12603

AFFECTED FILES
  mercurial/configitems.py
  mercurial/ui.py

CHANGE DETAILS

diff --git a/mercurial/ui.py b/mercurial/ui.py
--- a/mercurial/ui.py
+++ b/mercurial/ui.py
@@ -81,6 +81,8 @@
 git = 1
 showfunc = 1
 word-diff = 1
+# use merge-diff functionality to make `diff` of a merge easier to understand
+merge = yes
 """
 
 samplehgrcs = {
diff --git a/mercurial/configitems.py b/mercurial/configitems.py
--- a/mercurial/configitems.py
+++ b/mercurial/configitems.py
@@ -774,7 +774,6 @@
 b'diff',
 b'merge',
 default=False,
-experimental=True,
 )
 coreconfigitem(
 b'email',



To: durin42, #hg-reviewers
Cc: mercurial-patches, mercurial-devel
___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


mercurial@49159: 9 new changesets (9 on stable)

2022-05-04 Thread Mercurial Commits
9 new changesets (9 on stable) in mercurial:

https://www.mercurial-scm.org/repo/hg/rev/1b6e381521c5
changeset:   49151:1b6e381521c5
branch:  stable
user:Matt Harbison 
date:Mon May 02 22:04:59 2022 -0400
summary: doc: use an absolute path in sys.path to work around a python DLL 
loading bug

https://www.mercurial-scm.org/repo/hg/rev/eaaf4f98c9f1
changeset:   49152:eaaf4f98c9f1
branch:  stable
user:Raphaël Gomès 
date:Thu Apr 28 15:19:19 2022 +0200
summary: dirstate-v2: add flag to `debugstate` to print docket information

https://www.mercurial-scm.org/repo/hg/rev/308e45f7b455
changeset:   49153:308e45f7b455
branch:  stable
user:Raphaël Gomès 
date:Thu Apr 28 15:22:08 2022 +0200
summary: debugcommands: remove `debugdirstateignorepatternhash`

https://www.mercurial-scm.org/repo/hg/rev/51262af89efe
changeset:   49154:51262af89efe
branch:  stable
user:Raphaël Gomès 
date:Thu Apr 28 16:24:55 2022 +0200
summary: test-dirstate: use new `--docket` flag to get the data uuid

https://www.mercurial-scm.org/repo/hg/rev/c69adc82e7f7
changeset:   49155:c69adc82e7f7
branch:  stable
user:Raphaël Gomès 
date:Thu Apr 28 17:11:51 2022 +0200
summary: rust-dirstate-v2: show `unused_bytes` counter is not reset on 
total rewrite

https://www.mercurial-scm.org/repo/hg/rev/09984dc70352
changeset:   49156:09984dc70352
branch:  stable
user:Raphaël Gomès 
date:Thu Apr 28 17:15:35 2022 +0200
summary: rust-dirstate-v2: fix the unused bytes counter when rewriting the 
dirstate

https://www.mercurial-scm.org/repo/hg/rev/5d610521a285
changeset:   49157:5d610521a285
branch:  stable
user:Raphaël Gomès 
date:Wed May 04 15:48:13 2022 +0200
summary: test-dirstate: fix detection of Rust environment variable

https://www.mercurial-scm.org/repo/hg/rev/682b0ac92c0b
changeset:   49158:682b0ac92c0b
branch:  stable
user:Raphaël Gomès 
date:Wed May 04 15:49:20 2022 +0200
summary: test-dirstate: print something when the check is skipped

https://www.mercurial-scm.org/repo/hg/rev/363b687bb794
changeset:   49159:363b687bb794
branch:  stable
tag: tip
user:Mads Kiilerich 
date:Tue May 03 12:41:21 2022 +0200
summary: docs: use proper rst markup for preformatted blocks

-- 
Repository URL: https://www.mercurial-scm.org/repo/hg
___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


Re: [PATCH stable] docs: use proper rst markup for preformatted blocks

2022-05-04 Thread Augie Fackler
This appears to be landed as 363b6. Thanks!

On Tue, May 3, 2022 at 10:53 AM Mads Kiilerich  wrote:

> # HG changeset patch
> # User Mads Kiilerich 
> # Date 1651574481 -7200
> #  Tue May 03 12:41:21 2022 +0200
> # Branch stable
> # Node ID 1d257c4c15683ee998edcc7dd6caf5a4cb52c820
> # Parent  f2ef6a4f918f59f2ff01e5d4dc01c94ea35bd32f
> docs: use proper rst markup for preformatted blocks
>
> The multiple lines were re-flowed to a single line, both in man page and
> html.
>
> diff --git a/mercurial/helptext/rust.txt b/mercurial/helptext/rust.txt
> --- a/mercurial/helptext/rust.txt
> +++ b/mercurial/helptext/rust.txt
> @@ -28,7 +28,8 @@ in progress. For more experimental work
>  Checking for Rust
>  =
>
> -You may already have the Rust extensions depending on how you install
> Mercurial.
> +You may already have the Rust extensions depending on how you install
> +Mercurial::
>
>$ hg debuginstall | grep -i rust
>checking Rust extensions (installed)
> @@ -46,7 +47,7 @@ version to use.
>  Using pip
>  -
>
> -Users of `pip` can install the Rust extensions with the following command:
> +Users of `pip` can install the Rust extensions with the following
> command::
>
>$ pip install mercurial --global-option --rust --no-use-pep517
>
>
> ___
> Mercurial-devel mailing list
> Mercurial-devel@mercurial-scm.org
> https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel
>
___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


mercurial-devel | Failed pipeline for branch/stable | 363b687b

2022-05-04 Thread Heptapod


Pipeline #53609 has failed!

Project: mercurial-devel ( https://foss.heptapod.net/mercurial/mercurial-devel )
Branch: branch/stable ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/commits/branch/stable )

Commit: 363b687b ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/commit/363b687bb794ba4e84c8bee7558cfb533c5dceb9
 )
Commit Message: docs: use proper rst markup for preformatted bl...
Commit Author: kiilerix ( https://foss.heptapod.net/kiilerix )

Pipeline #53609 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/pipelines/53609 ) 
triggered by Raphaël Gomès ( https://foss.heptapod.net/raphael.gomes )
had 1 failed job.

Job #549666 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/jobs/549666/raw )

Stage: tests
Name: test-py2-rust

-- 
You're receiving this email because of your account on foss.heptapod.net.



___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


mercurial-devel | Failed pipeline for branch/stable | 682b0ac9

2022-05-04 Thread Heptapod


Pipeline #53607 has failed!

Project: mercurial-devel ( https://foss.heptapod.net/mercurial/mercurial-devel )
Branch: branch/stable ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/commits/branch/stable )

Commit: 682b0ac9 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/commit/682b0ac92c0bce5a5a4fc12e04814c1b9f80587f
 )
Commit Message: test-dirstate: print something when the check i...
Commit Author: Raphaël Gomès

Pipeline #53607 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/pipelines/53607 ) 
triggered by Administrator ( https://foss.heptapod.net/root )
had 1 failed job.

Job #549675 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/jobs/549675/raw )

Stage: tests
Name: test-py2-rust

-- 
You're receiving this email because of your account on foss.heptapod.net.



___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


mercurial-devel | Failed pipeline for branch/stable | 682b0ac9

2022-05-04 Thread Heptapod


Pipeline #53607 has failed!

Project: mercurial-devel ( https://foss.heptapod.net/mercurial/mercurial-devel )
Branch: branch/stable ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/commits/branch/stable )

Commit: 682b0ac9 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/commit/682b0ac92c0bce5a5a4fc12e04814c1b9f80587f
 )
Commit Message: test-dirstate: print something when the check i...
Commit Author: Raphaël Gomès

Pipeline #53607 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/pipelines/53607 ) 
triggered by Administrator ( https://foss.heptapod.net/root )
had 1 failed job.

Job #549638 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/jobs/549638/raw )

Stage: tests
Name: test-py2-rust

-- 
You're receiving this email because of your account on foss.heptapod.net.



___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


D12602: test-dirstate: print something when the check is skipped

2022-05-04 Thread Raphaël Gomès
Alphare created this revision.
Herald added a reviewer: hg-reviewers.
Herald added a subscriber: mercurial-patches.

REVISION SUMMARY
  This makes a programming error obvious in cases when it should not be skipped

REPOSITORY
  rHG Mercurial

BRANCH
  stable

REVISION DETAIL
  https://phab.mercurial-scm.org/D12602

AFFECTED FILES
  tests/test-dirstate.t

CHANGE DETAILS

diff --git a/tests/test-dirstate.t b/tests/test-dirstate.t
--- a/tests/test-dirstate.t
+++ b/tests/test-dirstate.t
@@ -136,6 +136,8 @@
   >   # Non-Rust always rewrites the whole dirstate
   >   if [ $# -eq 1 ] || ([ -n "$HGMODULEPOLICY" ] && [ -z 
"${HGMODULEPOLICY##*rust*}" ]) || [ -n "$RHG_INSTALLED_AS_HG" ]; then
   > test $current_uid = $(find_dirstate_uuid)
+  >   else
+  > echo "not testing because using Python implementation"
   >   fi
   > }
 
@@ -156,6 +158,7 @@
   $ dirstate_data_files | wc -l
*1 (re)
   $ dirstate_uuid_has_not_changed
+  not testing because using Python implementation (no-rust no-rhg !)
 
 Trigger an append with a small change
 
@@ -165,6 +168,7 @@
   $ dirstate_data_files | wc -l
*1 (re)
   $ dirstate_uuid_has_not_changed
+  not testing because using Python implementation (no-rust no-rhg !)
 
 Unused bytes counter is non-0 when appending
   $ touch file
@@ -178,6 +182,7 @@
   M dir2/f
   A file
   $ dirstate_uuid_has_not_changed
+  not testing because using Python implementation (no-rust no-rhg !)
 
   $ hg debugstate --docket | grep unused
   number of unused bytes: 0 (no-rust no-rhg !)



To: Alphare, #hg-reviewers
Cc: mercurial-patches, mercurial-devel
___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


D12601: test-dirstate: fix detection of Rust environment variable

2022-05-04 Thread Raphaël Gomès
Alphare created this revision.
Herald added a reviewer: hg-reviewers.
Herald added a subscriber: mercurial-patches.

REVISION SUMMARY
  The Rust path never actually worked. This change also improves clarity of the
  comment. The next change will ensure we print something when this check fails.

REPOSITORY
  rHG Mercurial

BRANCH
  stable

REVISION DETAIL
  https://phab.mercurial-scm.org/D12601

AFFECTED FILES
  tests/test-dirstate.t

CHANGE DETAILS

diff --git a/tests/test-dirstate.t b/tests/test-dirstate.t
--- a/tests/test-dirstate.t
+++ b/tests/test-dirstate.t
@@ -133,8 +133,8 @@
   > }
 
   $ dirstate_uuid_has_not_changed () {
-  >   # Pure Python always rewrites the whole dirstate
-  >   if [ $# -eq 1 ] || [ "$HGMODULEPOLICY" = *"rust"* ] || [ -n 
"$RHG_INSTALLED_AS_HG" ]; then
+  >   # Non-Rust always rewrites the whole dirstate
+  >   if [ $# -eq 1 ] || ([ -n "$HGMODULEPOLICY" ] && [ -z 
"${HGMODULEPOLICY##*rust*}" ]) || [ -n "$RHG_INSTALLED_AS_HG" ]; then
   > test $current_uid = $(find_dirstate_uuid)
   >   fi
   > }



To: Alphare, #hg-reviewers
Cc: mercurial-patches, mercurial-devel
___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel
diff --git a/mercurial/commands.py b/mercurial/commands.py
--- a/mercurial/commands.py
+++ b/mercurial/commands.py
@@ -2537,7 +2537,8 @@
 
:hg:`diff` may generate unexpected results for merges, as it will
default to comparing against the working directory's first
-   parent changeset if no revisions are specified.
+   parent changeset if no revisions are specified.  To diff against the
+   conflict regions, you can use `--config diff.merge=yes`.
 
 By default, the working directory files are compared to its first parent. 
To
 see the differences from another revision, use --from. To see the 
difference



To: mharbison72, #hg-reviewers
Cc: mercurial-patches, mercurial-devel
___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


Re: [PATCH] rebase: add boolean config item rebase.norebasesource

2022-05-04 Thread Augie Fackler


> On Apr 20, 2022, at 2:19 PM, C. Masloch  wrote:
> 
> # HG changeset patch
> # User C. Masloch 
> # Date 1650475479 -7200
> #  Wed Apr 20 19:24:39 2022 +0200
> # Node ID 4fd9ac0558249d24552b9efeed1ac77452c73319
> # Parent  f45e1618cbf68aca4e72b6fed8dd2acef6f39a10
> rebase: add boolean config item rebase.norebasesource
> 
> This allows to use rebase without recording a rebase_source extra
> field. This is useful for example to build a mirror converted from
> another SCM (such as svn) by converting only new revisions, and
> then incrementally add them to the destination by pulling from the
> newly converted (unrelated) repo and rebasing the new revisions
> onto the last old already stored changeset. Without this patch the
> rebased changesets would always receive some rebase_source that
> would depend on the particular history of the conversion process,
> instead of only depending on the original source revisions.

Interesting. An unusual process.

> 
> This is used to implement a hg mirror repo of SvarDOS (a partially
> nonfree but completely redistributable DOS distribution) in the
> scripts at https://hg.pushbx.org/ecm/svardos.scr/
> 
> In particular, cre.sh creates an svn mirror, upd.sh recreates an
> entire hg repo from the svn mirror (which takes too long to do in a
> regular job), and akt.sh uses hg convert with the config item
> convert.svn.startrev to incrementally convert only the two most
> recent revisions already found in the mirror destination plus any
> possible new revisions. If any are found, the temporary repo's
> changesets are pulled into the destination (as changesets from an
> unrelated repository). Then the changesets corresponding to the new
> revisions are rebased onto the prior final changeset. (Finally, the
> two remaining duplicates of the prior head and its parent are
> stripped from the destination repository.)
> 
> Without this patch, the particular rebase_source extra field would
> depend on the order and times at which akt.sh was used, instead of
> only depending on the source repository. In other words, whatever
> sequence of upd.sh and akt.sh is used at whatever times, it is
> desired that the final output repositories always match each other
> exactly.
> 
> diff --git a/hgext/rebase.py b/hgext/rebase.py
> --- a/hgext/rebase.py
> +++ b/hgext/rebase.py
> @@ -547,7 +547,10 @@
> date = self.date
> if date is None:
> date = ctx.date()
> -extra = {b'rebase_source': ctx.hex()}
> +if repo.ui.configbool(b'rebase', b'norebasesource'):
> +extra = {}
> +else:
> +extra = {b'rebase_source': ctx.hex()}
> for c in self.extrafns:
> c(ctx, extra)
> destphase = max(ctx.phase(), phases.draft)
> diff --git a/mercurial/configitems.py b/mercurial/configitems.py
> --- a/mercurial/configitems.py
> +++ b/mercurial/configitems.py
> @@ -2770,3 +2770,8 @@
> b'experimental.inmemory',
> default=False,
> )
> +coreconfigitem(
> +b'rebase',
> +b'norebasesource',
> +default=False,
> +)

I’m basically fine with this, but:

1) could you add some description in a comment about what this does here
2) could you mark it as experimental=True so it’s hidden from mundane uses?

Thanks!

> ___
> Mercurial-devel mailing list
> Mercurial-devel@mercurial-scm.org
> https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel

___
Mercurial-devel mailing list
Mercurial-devel@mercurial-scm.org
https://www.mercurial-scm.org/mailman/listinfo/mercurial-devel


mercurial-devel | Failed pipeline for branch/stable | 9889bf0f

2022-05-04 Thread Heptapod


Pipeline #53617 has failed!

Project: mercurial-devel ( https://foss.heptapod.net/mercurial/mercurial-devel )
Branch: branch/stable ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/commits/branch/stable )

Commit: 9889bf0f ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/commit/9889bf0fd960b761d8bd6a4fa381b42261b94a4d
 )
Commit Message: Added signature for changeset 0ddd5e1f5f67
Commit Author: Raphaël Gomès

Pipeline #53617 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/pipelines/53617 ) 
triggered by Administrator ( https://foss.heptapod.net/root )
had 4 failed jobs.

Job #549755 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/jobs/549755/raw )

Stage: tests
Name: test-py2
Job #549754 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/jobs/549754/raw )

Stage: tests
Name: rust-cargo-test-py3
Job #549761 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/jobs/549761/raw )

Stage: tests
Name: test-py2-chg
Job #549759 ( 
https://foss.heptapod.net/mercurial/mercurial-devel/-/jobs/549759/raw )

Stage: tests
Name: test-py3-rust
